
PVsystems
=========


.. automodule:: opendssdirect.PVsystems
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.PVsystems.AllNames

    Get a vector of strings with names of all PVSystems in active circuit.

.. function:: opendssdirect.PVsystems.Count

    The number of PVSystem objects currently defined in the active circuit.

.. function:: opendssdirect.PVsystems.First

    Set the first PVSystem to be active; returns 0 if none.

.. function:: opendssdirect.PVsystems.Idx

    Get the active PVSystem by index; 1..Count.Set the active PVSystem by index; 1..Count.

.. function:: opendssdirect.PVsystems.Irradiance

    Get the present value of the Irradiance property in W/sq-m.Set the present value of the Irradiance property in W/sq-m.

.. function:: opendssdirect.PVsystems.Name

    Get the name of the active PVSystem Object.Set the name of the active PVSystem Object.

.. function:: opendssdirect.PVsystems.Next

    Set the next PVSystem to be active; returns 0 if none.

.. function:: opendssdirect.PVsystems.kVARated

    Get the rated kVA.Set the rated kVA.

.. function:: opendssdirect.PVsystems.kW

    Get the kW output.

.. function:: opendssdirect.PVsystems.kvar

    Get the kvar value.Set the kvar value.

.. function:: opendssdirect.PVsystems.pf

    Get the power factor value.Set the power factor value.

